<?php
/**
 * Functions and custom controls for customizer
 *
 * @package WordPress
 * @subpackage SEO
 */

?>
<?php

/**
 * Custom styles for Customize
 */
function diagnoseo_customize_style() {
	wp_enqueue_style( 'customize-styles', get_template_directory_uri() . '/css/customize.css?v=' . time(), array(), 1 );
}
add_action( 'customize_controls_enqueue_scripts', 'diagnoseo_customize_style' );

/**
 * Setting registration functions
 */

/**
 * Registers color setting
 *
 * @param string $name Setting name.
 * @param string $default Default value.
 * @param string $label Control label text.
 * @param string $section Customizer section slug.
 * @param object $wp_customize The customizer object.
 * @param string $description Control description text.
 * @param string $transport Use 'postMessage' value to avoid reloading on change.
 */
function diagnoseo_register_color_setting( $name, $default, $label, $section, $wp_customize, $description = '', $transport = 'refresh' ) {
	$wp_customize->add_setting(
		$name,
		array(
			'sanitize_callback' => 'sanitize_hex_color',
			'default'           => $default,
			'transport'         => $transport,
		)
	);
	$setting_data = array(
		'label'    => $label,
		'section'  => $section,
		'settings' => $name,
	);

	if ( ! empty( $description ) ) {
		$setting_data['description'] = $description;
	}
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			$name,
			$setting_data
		)
	);
}

/**
 * Registers checkbox setting
 *
 * @param string  $name Setting name.
 * @param boolean $default Default value.
 * @param string  $label Control label text.
 * @param string  $section Customizer section slug.
 * @param object  $wp_customize The customizer object.
 * @param string  $description Control description text.
 */
function diagnoseo_register_checkbox_setting( $name, $default, $label, $section, $wp_customize, $description = '' ) {
	$wp_customize->add_setting(
		$name,
		array(
			'sanitize_callback' => 'diagnoseo_sanitize_checkbox',
			'default'           => $default,
		)
	);
	$wp_customize->add_control(
		$name,
		array(
			'label'       => $label,
			'section'     => $section,
			'settings'    => $name,
			'type'        => 'checkbox',
			'description' => $description,
		)
	);
}

/**
 * Sanitizes checkbox value
 *
 * @param boolean $checked Checkbox value.
 */
function diagnoseo_sanitize_checkbox( $checked ) {
	return isset( $checked ) && ( true === $checked || 1 === $checked );
}